@@ -17,11 +17,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from __future__ import annotations
-from dataclasses import dataclass
 
+from dataclasses import dataclass
 from typing import Dict, List, Optional, Any
 
-from .common import ExecutionMatch, ExecutionMode, _BaseDataObject
+from .common import ExecutionMatch, ExecutionMode, _BaseDataObject, ExecutionStatus
 
 
 @dataclass(frozen=True)
@@ -85,13 +85,13 @@ class ExecutionDetailsAuxFunctions(_BaseDataObject):
     @property
     def errored(self) -> bool:
         return self.title.errored \
-            or self.runbook.errored \
-            or self.severity.errored \
-            or self.reference.errored \
-            or self.description.errored \
-            or self.destinations.errored \
-            or self.dedup.errored \
-            or self.alert_context.errored
+               or self.runbook.errored \
+               or self.severity.errored \
+               or self.reference.errored \
+               or self.description.errored \
+               or self.destinations.errored \
+               or self.dedup.errored \
+               or self.alert_context.errored
 
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionDetailsAuxFunctions:
@@ -157,8 +157,10 @@ class ExecutionOutput(_BaseDataObject):
 @dataclass(frozen=True)
 class ExecutionResult(_BaseDataObject):
     output_mode: ExecutionMode
+    status: Optional[ExecutionStatus] = None
     url: Optional[str] = None
     data: Optional[List[ExecutionOutput]] = None
+    metadata: Optional[Dict[str, str]] = None
 
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionResult:
@@ -167,8 +169,15 @@ class ExecutionResult(_BaseDataObject):
             obj = ExecutionOutput.from_json(json_str)
             outputs.append(obj)
 
+        status: Optional[ExecutionStatus] = None
+        data_status = data.get('status', None)
+        if data_status is not None:
+            status = ExecutionStatus(data_status)
+
         return cls(
             url=data['url'],
+            status=status,
             data=outputs,
+            metadata=data.get('metadata', None),
             output_mode=ExecutionMode(data['output_mode']),
         )
